bbprep.generators.BondRange
===========================

.. currentmodule:: bbprep.generators

.. autoclass:: BondRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BondRange.smarts
      ~BondRange.expected_num_atoms
      ~BondRange.scanned_ids
      ~BondRange.scanned_range
   
   